@@ -5,15 +5,15 @@
     <name>MainWindow</name>
     <message>
         <location filename="../mainwindow.ui" line="14"/>
-        <location filename="../mainwindow.cpp" line="48"/>
-        <location filename="../mainwindow.cpp" line="509"/>
+        <location filename="../mainwindow.cpp" line="47"/>
+        <location filename="../mainwindow.cpp" line="513"/>
         <source>MX Conky</source>
-        <translation type="unfinished"></translation>
+        <translation>MX קונקי</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="20"/>
         <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;This app enables detailed changes to the active conky. It supplements Conky Manager, which should be used for basic settings.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
-        <translation type="unfinished"></translation>
+        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p align=&quot;center&quot;&gt;&lt;span style=&quot; font-size:11pt; font-weight:600;&quot;&gt;היישום הזה מאפשר שינויים מפורטים לקונקי הפעיל. הוא משלים למנהל של קונקי, שמשמש לצרכים בסיסיים יותר.&lt;/span&gt;&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="73"/>
@@ -38,12 +38,12 @@
     <message>
         <location filename="../mainwindow.ui" line="185"/>
         <source>Conky Name</source>
-        <translation type="unfinished"></translation>
+        <translation>שם קונקי</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="211"/>
         <source>Conky Manager</source>
-        <translation type="unfinished"></translation>
+        <translation>מנהל קונקי</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="235"/>
@@ -73,7 +73,7 @@
     <message>
         <location filename="../mainwindow.ui" line="295"/>
         <source>NOTE: changes last only for the current session</source>
-        <translation type="unfinished"></translation>
+        <translation>לתשומת לבך: השינויים נשמרים רק בהפעלה הנוכחית</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="365"/>
@@ -180,27 +180,27 @@
     <message>
         <location filename="../mainwindow.ui" line="1480"/>
         <source>Color5</source>
-        <translation type="unfinished">צבע4 {5?}</translation>
+        <translation>צבע5</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1595"/>
         <source>Color6</source>
-        <translation type="unfinished">צבע4 {6?}</translation>
+        <translation>צבע6</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1710"/>
         <source>Color7</source>
-        <translation type="unfinished">צבע4 {7?}</translation>
+        <translation>צבע7</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1825"/>
         <source>Color8</source>
-        <translation type="unfinished">צבע4 {8?}</translation>
+        <translation>צבע8</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="1940"/>
         <source>Color9</source>
-        <translation type="unfinished">צבע4 {9?}</translation>
+        <translation>צבע9</translation>
     </message>
     <message>
         <location filename="../mainwindow.ui" line="2048"/>
@@ -248,83 +248,83 @@
         <translation>Alt+N</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="508"/>
+        <location filename="../mainwindow.cpp" line="512"/>
         <source>About MX Conky</source>
         <translation>על MX Conky</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="509"/>
+        <location filename="../mainwindow.cpp" line="514"/>
         <source>Version: </source>
         <translation>גירסה:</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="510"/>
+        <location filename="../mainwindow.cpp" line="515"/>
         <source>GUI program for configuring Conky in MX Linux</source>
-        <translation type="unfinished"></translation>
+        <translation>תוכנית חזותית להגדרת קונקי ב־MX לינוקס</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="512"/>
+        <location filename="../mainwindow.cpp" line="518"/>
         <source>Copyright (c) MX Linux</source>
         <translation>זכויות היוצרים (c) שמורות ל־MX Linux</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="513"/>
+        <location filename="../mainwindow.cpp" line="519"/>
         <source>License</source>
         <translation>רשיון</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="514"/>
-        <location filename="../mainwindow.cpp" line="527"/>
+        <location filename="../mainwindow.cpp" line="520"/>
+        <location filename="../mainwindow.cpp" line="533"/>
         <source>Changelog</source>
         <translation>יומן שינויים</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="515"/>
+        <location filename="../mainwindow.cpp" line="521"/>
         <source>Cancel</source>
         <translation>ביטול</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="535"/>
+        <location filename="../mainwindow.cpp" line="544"/>
         <source>&amp;Close</source>
         <translation>&amp;סגירה</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="553"/>
+        <location filename="../mainwindow.cpp" line="562"/>
         <source>MX Conky Help</source>
-        <translation type="unfinished"></translation>
+        <translation>העזרה של MX קונקי</translation>
     </message>
 </context>
 <context>
     <name>QObject</name>
     <message>
-        <location filename="../main.cpp" line="64"/>
-        <location filename="../mainwindow.cpp" line="670"/>
+        <location filename="../main.cpp" line="65"/>
+        <location filename="../mainwindow.cpp" line="648"/>
         <source>Select Conky Manager config file</source>
-        <translation type="unfinished"></translation>
+        <translation>נא לבחור קובץ הגדרות של מנהל קונקי</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="80"/>
+        <location filename="../main.cpp" line="82"/>
         <source>Conky Data Update</source>
-        <translation type="unfinished"></translation>
+        <translation>עדכון נתונים של קונקי</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="81"/>
+        <location filename="../main.cpp" line="83"/>
         <source>The MX Conky data set has been updated. &lt;p&gt;&lt;p&gt;                                  Copy from the folder where it is located &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;/usr/share/mx-conky-data/themes&lt;/a&gt;                                   whatever you wish to your Home hidden conky folder &lt;a href=&quot;%1/.conky&quot;&gt;~/.conky&lt;/a&gt;.                                   Be careful not to overwrite any conkies you have changed.</source>
-        <translation type="unfinished"></translation>
+        <translation>הנתונים של MX עודכנו. &lt;p&gt;&lt;p&gt;                                  נא להעתיק אותם מתיקיית המקור שלהם &lt;a href=&quot;/usr/share/mx-conky-data/themes&quot;&gt;‎/usr/share/mx-conky-data/themes&lt;/a&gt;                                   מה שנחוץ לך לתיקייה הנסתרת בתיקיית הבית שלך &lt;a href=&quot;%1/.conky&quot;&gt;‎~/.conky&lt;/a&gt;.                                   נא להיזהר לא לדרוס הגדרות קודמות של קונקי שנערכו.</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="112"/>
-        <location filename="../main.cpp" line="143"/>
+        <location filename="../main.cpp" line="117"/>
+        <location filename="../main.cpp" line="148"/>
         <source>Error</source>
         <translation>שגיאה</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="113"/>
+        <location filename="../main.cpp" line="118"/>
         <source>Could not find conky-manager, please install it before running mx-conky</source>
-        <translation type="unfinished"></translation>
+        <translation>לא ניתן למצוא את conky-manager, נא להתקין אותו בטרם הפעלת mx-conky</translation>
     </message>
     <message>
-        <location filename="../main.cpp" line="143"/>
+        <location filename="../main.cpp" line="148"/>
         <source>You must run this program as normal user</source>
         <translation>עליך להריץ את התכנית הזאת כמשתמש רגיל</translation>
     </message>
